@@ -19,7 +19,10 @@ def bagi_angka(a,b):
 def kurang_angka(a,b):
     return a-b
 
-input("Press Enter to continue...")
+def add(a):
+    return a
+
+input("DD GUI Library has been installed.")
 
 class MyForm(QDialog):
 
